pub enum PaginatorState {
Initial,
FetchingTargetEvent,
Idle,
Paginating,
}Expand description
Current state of a Paginator.
Variants
Initial
The initial state of the paginator.
FetchingTargetEvent
The paginator is fetching the target initial event.
Idle
The target initial event could be found, zero or more paginations have happened since then, and the paginator is at rest now.
Paginating
The paginator is… paginating one direction or another.